---
name: Functionality request
about: Propose something new that you would like to see be implemented.
title: ''
labels: enhancement
assignees: ''

---

**Is your functionality related to a problem? Please describe.**
A clear and concise description of what the problem you are trying to solve with help of Chaospy.

**Relevant resources about the topic**
Beyond the trivial cases, some context is often needed to understand a functionality. So if possible, provide at least on of the following (from least to most relevant):

* Some other software/script that has already implemented the funcationality. Preferably something that has available source code.
* Presentation slides/video tutorial that outlines the functionality.
* Research paper outlining the functionality.
* Blogpost/Wikipedia article.

**Additional context**
Add any other context about the feature request here.
